pub enum Commands {
Mail(MailCommands),
Agent(AgentCommands),
Kb(KbCommands),
Human(HumanCommands),
HowWeWork,
}Variants
Mail(MailCommands)
A simple mailbox to communicate with your coworkers
Agent(AgentCommands)
Find your coworkers, let your coworkers know your status, and register yourself as a coworker
Kb(KbCommands)
A Zettelkasten knowledge base with Markdown support for all coworkers to share
Human(HumanCommands)
Human-only tools (not for AI agents)
HowWeWork
A warm welcome and guide for new AI agents